@@ -341,7 +341,10 @@ class SearchQueryCompiler(Elasticsearch6SearchQueryCompiler):
     ):
         self.es_filters = es_filters or {}
         self.es_ordering = es_ordering or []
-        self.facet_table = get_facet_table(queryset.model.get_facets())
+        if hasattr(queryset.model, "get_facets"):
+            self.facet_table = get_facet_table(queryset.model.get_facets())
+        else:
+            self.facet_table = {}
 
         super().__init__(
             queryset,
@@ -471,7 +474,10 @@ class SearchQueryCompiler(Elasticsearch6SearchQueryCompiler):
                 field = self._get_filterable_field(facet_name)
                 if field is not None:
                     column_name = self.mapping.get_field_column_name(field)
-                    es_filters.append({"match": {column_name: values}})
+                    if isinstance(values, list):
+                        es_filters.append({"terms": {column_name: values}})
+                    else:
+                        es_filters.append({"match": {column_name: values}})
 
                 continue
 
